@@ -17,11 +17,11 @@
 #  limitations under the License.
 ###############################################################################
 
-import cherrypy
 import json
 
 from ..describe import Description, describeRoute
-from ..rest import Resource, RestException, filtermodel, loadmodel
+from ..rest import Resource, RestException, filtermodel, loadmodel, \
+    setResponseHeader
 from girder.api import access
 from girder.constants import AccessType, TokenScope
 from girder.models.model_base import AccessException
@@ -48,7 +48,7 @@ class Collection(Resource):
     @filtermodel(model='collection')
     @describeRoute(
         Description('List or search for collections.')
-        .responseClass('Collection')
+        .responseClass('Collection', array=True)
         .param('text', "Pass this to perform a text search for collections.",
                required=False)
         .pagingParams(defaultSort='name')
@@ -130,9 +130,10 @@ class Collection(Resource):
         .errorResponse('Read access was denied for the collection.', 403)
     )
     def downloadCollection(self, collection, params):
-        cherrypy.response.headers['Content-Type'] = 'application/zip'
-        cherrypy.response.headers['Content-Disposition'] = \
-            'attachment; filename="%s%s"' % (collection['name'], '.zip')
+        setResponseHeader('Content-Type', 'application/zip')
+        setResponseHeader(
+            'Content-Disposition',
+            'attachment; filename="%s%s"' % (collection['name'], '.zip'))
 
         user = self.getCurrentUser()
         mimeFilter = params.get('mimeFilter')
