@@ -137,10 +137,10 @@ class File(Resource):
         .notes('This is only required in certain non-standard upload '
                'behaviors. Clients should know which behavior models require '
                'the finalize step to be called in their behavior handlers.')
-        .param('uploadId', 'The ID of the upload record.', paramType='form')
-        .errorResponse('ID was invalid.')
-        .errorResponse('The upload does not require finalization.')
-        .errorResponse('Not enough bytes have been uploaded.')
+        .param('uploadId', 'The ID of the upload record.', paramType='formData')
+        .errorResponse(('ID was invalid.',
+                        'The upload does not require finalization.',
+                        'Not enough bytes have been uploaded.'))
         .errorResponse('You are not the user who initiated the upload.', 403)
     )
     def finalizeUpload(self, params):
@@ -193,16 +193,16 @@ class File(Resource):
     @describeRoute(
         Description('Upload a chunk of a file with multipart/form-data.')
         .consumes('multipart/form-data')
-        .param('uploadId', 'The ID of the upload record.', paramType='form')
+        .param('uploadId', 'The ID of the upload record.', paramType='formData')
         .param('offset', 'Offset of the chunk in the file.', dataType='integer',
-               paramType='form')
+               paramType='formData')
         .param('chunk', 'The actual bytes of the chunk. For external upload '
                'behaviors, this may be set to an opaque string that will be '
                'handled by the assetstore adapter.',
-               dataType='File', paramType='body')
-        .errorResponse('ID was invalid.')
-        .errorResponse('Received too many bytes.')
-        .errorResponse('Chunk is smaller than the minimum size.')
+               dataType='file', paramType='formData')
+        .errorResponse(('ID was invalid.',
+                        'Received too many bytes.',
+                        'Chunk is smaller than the minimum size.'))
         .errorResponse('You are not the user who initiated the upload.', 403)
         .errorResponse('Failed to store upload.', 500)
     )
@@ -334,7 +334,7 @@ class File(Resource):
     def cancelUpload(self, upload, params):
         user = self.getCurrentUser()
 
-        if upload['userId'] != user['_id'] and not user.get('admin'):
+        if upload['userId'] != user['_id'] and not user['admin']:
             raise AccessException('You did not initiate this upload.')
 
         self.model('upload').cancelUpload(upload)
