@@ -17,10 +17,9 @@
 #  limitations under the License.
 ###############################################################################
 
-import cherrypy
-
 from ..describe import Description, describeRoute
-from ..rest import Resource, RestException, filtermodel, loadmodel
+from ..rest import Resource, RestException, filtermodel, loadmodel, \
+    setResponseHeader
 from girder.utility import ziputil
 from girder.constants import AccessType, TokenScope
 from girder.api import access
@@ -46,7 +45,7 @@ class Item(Resource):
     @filtermodel(model='item')
     @describeRoute(
         Description('List or search for items.')
-        .responseClass('Item')
+        .responseClass('Item', array=True)
         .param('folderId', "Pass this to list all items in a folder.",
                required=False)
         .param('text', "Pass this to perform a full text search for items.",
@@ -174,9 +173,9 @@ class Item(Resource):
         .param('id', 'The ID of the item.', paramType='path')
         .param('body', 'A JSON object containing the metadata keys to add',
                paramType='body')
-        .errorResponse('ID was invalid.')
-        .errorResponse('Invalid JSON passed in request body.')
-        .errorResponse('Metadata key name was invalid.')
+        .errorResponse(('ID was invalid.',
+                        'Invalid JSON passed in request body.',
+                        'Metadata key name was invalid.'))
         .errorResponse('Write access was denied for the item.', 403)
     )
     def setMetadata(self, item, params):
@@ -194,9 +193,10 @@ class Item(Resource):
         return self.model('item').setMetadata(item, metadata)
 
     def _downloadMultifileItem(self, item, user):
-        cherrypy.response.headers['Content-Type'] = 'application/zip'
-        cherrypy.response.headers['Content-Disposition'] =\
-            'attachment; filename="%s%s"' % (item['name'], '.zip')
+        setResponseHeader('Content-Type', 'application/zip')
+        setResponseHeader(
+            'Content-Disposition',
+            'attachment; filename="%s%s"' % (item['name'], '.zip'))
 
         def stream():
             zip = ziputil.ZipGenerator(item['name'])
@@ -212,7 +212,7 @@ class Item(Resource):
     @filtermodel(model='file')
     @describeRoute(
         Description('Get the files within an item.')
-        .responseClass('File')
+        .responseClass('File', array=True)
         .param('id', 'The ID of the item.', paramType='path')
         .pagingParams(defaultSort='name')
         .errorResponse('ID was invalid.')
@@ -296,10 +296,10 @@ class Item(Resource):
         .param('folderId', 'The ID of the parent folder.', required=False)
         .param('name', 'Name for the new item.', required=False)
         .param('description', "Description for the new item.", required=False)
-        .errorResponse()
-        .errorResponse('ID was invalid.')
-        .errorResponse('Read access was denied on the original item.', 403)
-        .errorResponse('Write access was denied on the parent folder.', 403)
+        .errorResponse(('A parameter was invalid.',
+                        'ID was invalid.'))
+        .errorResponse('Read access was denied on the original item.\n\n'
+                       'Write access was denied on the parent folder.', 403)
     )
     def copyItem(self, item, params):
         """
