@@ -28,8 +28,7 @@ import os
 from girder.api import access
 from girder.constants import SettingKey, TokenScope, VERSION
 from girder.models.model_base import GirderException
-from girder.utility import plugin_utilities
-from girder.utility import system
+from girder.utility import install, plugin_utilities, system
 from girder.utility.progress import ProgressContext
 from ..describe import API_VERSION, Description, describeRoute
 from ..rest import Resource, RestException
@@ -57,6 +56,7 @@ class System(Resource):
         self.route('GET', ('check',), self.systemStatus)
         self.route('PUT', ('check',), self.systemConsistencyCheck)
         self.route('GET', ('log',), self.getLog)
+        self.route('POST', ('web_build',), self.buildWebCode)
 
     @access.admin
     @describeRoute(
@@ -411,16 +411,31 @@ class System(Resource):
                     yield data
         return stream
 
+    @access.admin
+    @describeRoute(
+        Description('Rebuild web client code.')
+        .param('progress', 'Whether to record progress on this task.', required=False,
+               dataType='boolean', default=False)
+        .param('dev', 'Whether to build for development mode.', required=False,
+               dataType='boolean', default=False)
+    )
+    def buildWebCode(self, params):
+        progress = self.boolParam('progress', params, default=False)
+        dev = self.boolParam('dev', params, default=False)
+        user = self.getCurrentUser()
+
+        with ProgressContext(progress, user=user, title='Building web client code') as progress:
+            install.runWebBuild(dev=dev, progress=progress)
+
     def _fixBaseParents(self, progress):
         fixes = 0
-        user = self.getCurrentUser()
         models = ['folder', 'item']
         steps = sum(self.model(model).find().count() for model in models)
         progress.update(total=steps, current=0)
         for model in models:
             for doc in self.model(model).find():
                 progress.update(increment=1)
-                baseParent = self.model(model).parentsToRoot(doc, user=user)[0]
+                baseParent = self.model(model).parentsToRoot(doc, force=True)[0]
                 baseParentType = baseParent['type']
                 baseParentId = baseParent['object']['_id']
                 if (doc['baseParentType'] != baseParentType or
@@ -435,27 +450,25 @@ class System(Resource):
 
     def _pruneOrphans(self, progress):
         count = 0
-        user = self.getCurrentUser()
         models = ['folder', 'item', 'file']
         steps = sum(self.model(model).find().count() for model in models)
         progress.update(total=steps, current=0)
         for model in models:
             for doc in self.model(model).find():
                 progress.update(increment=1)
-                if self.model(model).isOrphan(doc, user=user):
+                if self.model(model).isOrphan(doc):
                     self.model(model).remove(doc)
                     count += 1
         return count
 
     def _recalculateSizes(self, progress):
         fixes = 0
-        user = self.getCurrentUser()
         models = ['collection', 'user']
         steps = sum(self.model(model).find().count() for model in models)
         progress.update(total=steps, current=0)
         for model in models:
             for doc in self.model(model).find():
                 progress.update(increment=1)
-                _, f = self.model(model).updateSize(doc, user)
+                _, f = self.model(model).updateSize(doc)
                 fixes += f
         return fixes
