@@ -23,8 +23,7 @@ import datetime
 
 from ..describe import Description, describeRoute
 from girder.api import access
-from girder.api.rest import Resource, RestException, AccessException,\
-    filtermodel, loadmodel
+from girder.api.rest import Resource, RestException, AccessException, filtermodel, loadmodel
 from girder.constants import AccessType, SettingKey, TokenScope
 from girder.models.token import genToken
 from girder.utility import mail_utils
@@ -60,7 +59,7 @@ class User(Resource):
     @filtermodel(model='user')
     @describeRoute(
         Description('List or search for users.')
-        .responseClass('User')
+        .responseClass('User', array=True)
         .param('text', "Pass this to perform a full text search for items.",
                required=False)
         .pagingParams(defaultSort='lastName')
@@ -128,26 +127,7 @@ class User(Resource):
                 raise RestException('Invalid HTTP Authorization header', 401)
 
             login, password = credentials.split(':', 1)
-
-            login = login.lower().strip()
-            loginField = 'email' if '@' in login else 'login'
-
-            user = self.model('user').findOne({loginField: login})
-            if user is None:
-                raise RestException('Login failed.', code=403)
-
-            if not self.model('password').authenticate(user, password):
-                raise RestException('Login failed.', code=403)
-
-            if self.model('user').emailVerificationRequired(user):
-                raise RestException(
-                    'Email verification required.', code=403,
-                    extra='emailVerification')
-
-            if self.model('user').adminApprovalRequired(user):
-                raise RestException(
-                    'Account approval required.', code=403,
-                    extra='accountApproval')
+            user = self.model('user').authenticate(login, password)
 
             setattr(cherrypy.request, 'girderUser', user)
             token = self.sendAuthTokenCookie(user)
@@ -212,15 +192,15 @@ class User(Resource):
             email=params['email'], firstName=params['firstName'],
             lastName=params['lastName'], admin=admin)
 
+        outputUser = self.model('user').filter(user, user)
         if not currentUser and self.model('user').canLogin(user):
             setattr(cherrypy.request, 'girderUser', user)
             token = self.sendAuthTokenCookie(user)
-            user['authToken'] = {
+            outputUser['authToken'] = {
                 'token': token['_id'],
                 'expires': token['expires']
             }
-
-        return user
+        return outputUser
 
     @access.user
     @loadmodel(map={'id': 'userToDelete'}, model='user', level=AccessType.ADMIN)
@@ -248,8 +228,8 @@ class User(Resource):
         .param('status', 'The account status (admin access required)',
                required=False, enum=['pending', 'enabled', 'disabled'])
         .errorResponse()
-        .errorResponse('You do not have write access for this user.', 403)
-        .errorResponse('Must be an admin to create an admin.', 403)
+        .errorResponse(('You do not have write access for this user.',
+                        'Must be an admin to create an admin.'), 403)
     )
     def updateUser(self, user, params):
         self.requireParams(('firstName', 'lastName', 'email'), params)
@@ -268,15 +248,16 @@ class User(Resource):
                     raise AccessException('Only admins may change admin state.')
 
         # Only admins can change status
-        if 'status' in params and params['status'] != user['status']:
-            if self.getCurrentUser()['admin']:
-                user['status'] = params['status']
-                if user['status'] == 'enabled':
-                    self.model('user')._sendApprovedEmail(user)
-            else:
+        if 'status' in params and params['status'] != user.get('status', 'enabled'):
+            if not self.getCurrentUser()['admin']:
                 raise AccessException('Only admins may change status.')
+            if user['status'] == 'pending' and params['status'] == 'enabled':
+                # Send email on the 'pending' -> 'enabled' transition
+                self.model('user')._sendApprovedEmail(user)
+            user['status'] = params['status']
 
-        return self.model('user').save(user)
+        user = self.model('user').save(user)
+        return self.model('user').filter(user, user)
 
     @access.admin
     @loadmodel(model='user', level=AccessType.ADMIN)
@@ -298,8 +279,8 @@ class User(Resource):
         Description('Change your password.')
         .param('old', 'Your current password or a temporary access token.')
         .param('new', 'Your new password.')
-        .errorResponse('You are not logged in.', 401)
-        .errorResponse('Your old password is incorrect.', 401)
+        .errorResponse(('You are not logged in.',
+                        'Your old password is incorrect.'), 401)
         .errorResponse('Your new password is invalid.')
     )
     def changePassword(self, params):
@@ -372,7 +353,7 @@ class User(Resource):
         token = self.model('token').createToken(
             user, days=1, scope=TokenScope.TEMPORARY_USER_AUTH)
 
-        url = '%s/#useraccount/%s/token/%s' % (
+        url = '%s#useraccount/%s/token/%s' % (
             mail_utils.getEmailUrlPrefix(), str(user['_id']), str(token['_id']))
 
         html = mail_utils.renderTemplate('temporaryAccess.mako', {
@@ -456,13 +437,13 @@ class User(Resource):
 
         user['emailVerified'] = True
         self.model('token').remove(token)
-        self.model('user').save(user)
+        user = self.model('user').save(user)
 
         if self.model('user').canLogin(user):
             setattr(cherrypy.request, 'girderUser', user)
             authToken = self.sendAuthTokenCookie(user)
             return {
-                'user': user,
+                'user': self.model('user').filter(user, user),
                 'authToken': {
                     'token': authToken['_id'],
                     'expires': authToken['expires'],
@@ -472,7 +453,7 @@ class User(Resource):
             }
         else:
             return {
-                'user': user,
+                'user': self.model('user').filter(user, user),
                 'message': 'Email verification succeeded.'
             }
 
