@@ -1,7 +1,22 @@
+import _ from 'underscore';
+
+import SearchFieldWidget from 'girder/views/widgets/SearchFieldWidget';
+import View from 'girder/views/View';
+import events from 'girder/events';
+import { restRequest, cancelRestRequests } from 'girder/rest';
+import { restartServerPrompt } from 'girder/server';
+
+import SystemConfigurationTemplate from 'girder/templates/body/systemConfiguration.pug';
+
+import 'girder/stylesheets/body/systemConfig.styl';
+
+import 'bootstrap/js/collapse';
+import 'bootstrap/js/tooltip';
+
 /**
  * The system config page for administrators.
  */
-girder.views.SystemConfigurationView = girder.View.extend({
+var SystemConfigurationView = View.extend({
     events: {
         'submit .g-settings-form': function (event) {
             event.preventDefault();
@@ -9,13 +24,22 @@ girder.views.SystemConfigurationView = girder.View.extend({
             this.$('#g-settings-error-message').empty();
 
             var settings = _.map(this.settingsKeys, function (key) {
+                if (key === 'core.route_table') {
+                    return {
+                        key: key,
+                        value: _.object(_.map($('.g-core-route-table'), function (el) {
+                            return [$(el).data('webroot-name'), $(el).val()];
+                        }))
+                    };
+                }
+
                 return {
                     key: key,
                     value: this.$('#g-' + key.replace(/[_.]/g, '-')).val() || null
                 };
             }, this);
 
-            girder.restRequest({
+            restRequest({
                 type: 'PUT',
                 path: 'system/setting',
                 data: {
@@ -24,7 +48,7 @@ girder.views.SystemConfigurationView = girder.View.extend({
                 error: null
             }).done(_.bind(function () {
                 this.$('.g-submit-settings').removeClass('disabled');
-                girder.events.trigger('g:alert', {
+                events.trigger('g:alert', {
                     icon: 'ok',
                     text: 'Settings saved.',
                     type: 'success',
@@ -37,11 +61,12 @@ girder.views.SystemConfigurationView = girder.View.extend({
         },
         'click .g-edit-collection-create-policy': function () {
             this.collectionCreateAccessWidget.render();
-        }
+        },
+        'click #g-restart-server': restartServerPrompt
     },
 
     initialize: function () {
-        girder.cancelRestRequests('fetch');
+        cancelRestRequests('fetch');
 
         var keys = [
             'core.cookie_lifetime',
@@ -60,10 +85,11 @@ girder.views.SystemConfigurationView = girder.View.extend({
             'core.cors.allow_headers',
             'core.add_to_group_policy',
             'core.collection_create_policy',
-            'core.user_default_folders'
+            'core.user_default_folders',
+            'core.route_table'
         ];
         this.settingsKeys = keys;
-        girder.restRequest({
+        restRequest({
             path: 'system/setting',
             type: 'GET',
             data: {
@@ -72,7 +98,7 @@ girder.views.SystemConfigurationView = girder.View.extend({
             }
         }).done(_.bind(function (resp) {
             this.settings = resp;
-            girder.restRequest({
+            restRequest({
                 path: 'system/setting',
                 type: 'GET',
                 data: {
@@ -87,9 +113,15 @@ girder.views.SystemConfigurationView = girder.View.extend({
     },
 
     render: function () {
-        this.$el.html(girder.templates.systemConfiguration({
+        this.$el.html(SystemConfigurationTemplate({
             settings: this.settings,
             defaults: this.defaults,
+            routes: this.settings['core.route_table'] || this.defaults['core.route_table'],
+            routeKeys: _.sortBy(_.keys(this.settings['core.route_table'] ||
+                                       this.defaults['core.route_table']),
+                                function (a) {
+                                    return a.indexOf('core_') === 0 ? -1 : 0;
+                                }),
             JSON: window.JSON
         }));
 
@@ -99,7 +131,7 @@ girder.views.SystemConfigurationView = girder.View.extend({
             delay: {show: 200}
         });
 
-        this.searchWidget = new girder.views.SearchFieldWidget({
+        this.searchWidget = new SearchFieldWidget({
             el: this.$('.g-collection-create-policy-container .g-search-container'),
             parentView: this,
             types: ['user', 'group'],
@@ -124,7 +156,7 @@ girder.views.SystemConfigurationView = girder.View.extend({
                 if (!_.contains(settingValue.users, result.id)) {
                     settingValue.users.push(result.id);
                 } else {
-                    girder.events.trigger('g:alert', {
+                    events.trigger('g:alert', {
                         icon: 'ok',
                         text: 'User already exists in current policy.',
                         type: 'warning',
@@ -136,7 +168,7 @@ girder.views.SystemConfigurationView = girder.View.extend({
                 if (!_.contains(settingValue.groups, result.id)) {
                     settingValue.groups.push(result.id);
                 } else {
-                    girder.events.trigger('g:alert', {
+                    events.trigger('g:alert', {
                         icon: 'ok',
                         text: 'Group already exists in current policy.',
                         type: 'warning',
@@ -153,6 +185,5 @@ girder.views.SystemConfigurationView = girder.View.extend({
     }
 });
 
-girder.router.route('settings', 'settings', function () {
-    girder.events.trigger('g:navigateTo', girder.views.SystemConfigurationView);
-});
+export default SystemConfigurationView;
+
