@@ -43,18 +43,6 @@ class Collection(AccessControlledModel):
             '_id', 'name', 'description', 'public', 'created', 'updated',
             'size'))
 
-    def filter(self, *args, **kwargs):
-        """
-        Preserved override for kwarg backwards compatibility. Prior to the
-        refactor for centralizing model filtering, this method's first formal
-        parameter was called "collection", whereas the centralized version's
-        first parameter is called "doc". This override simply detects someone
-        using the old kwarg and converts it to the new form.
-        """
-        if 'collection' in kwargs:
-            args = [kwargs.pop('collection')] + list(args)
-        return super(Collection, self).filter(*args, **kwargs)
-
     def validate(self, doc):
         doc['name'] = doc['name'].strip()
         if doc['description']:
@@ -275,7 +263,7 @@ class Collection(AccessControlledModel):
         :param user: The user to test.
         :returns: bool
         """
-        if user['admin'] is True:
+        if user['admin']:
             return True
 
         policy = self.model('setting').get(SettingKey.COLLECTION_CREATE_POLICY)
@@ -317,25 +305,26 @@ class Collection(AccessControlledModel):
             return sum(1 for _ in folderModel.filterResultsByPermission(
                 cursor=folders, user=user, level=level))
 
-    def updateSize(self, doc, user):
+    def updateSize(self, doc):
         """
         Recursively recomputes the size of this collection and its underlying
         folders and fixes the sizes as needed.
 
         :param doc: The collection.
         :type doc: dict
-        :param user: The admin user for permissions.
-        :type user: dict
         """
         size = 0
         fixes = 0
-        folders = self.model('folder').childFolders(doc, 'collection', user)
+        folders = self.model('folder').find({
+            'parentId': doc['_id'],
+            'parentCollection': 'collection'
+        })
         for folder in folders:
             # fix folder size if needed
-            _, f = self.model('folder').updateSize(folder, user)
+            _, f = self.model('folder').updateSize(folder)
             fixes += f
             # get total recursive folder size
-            folder = self.model('folder').load(folder['_id'], user=user)
+            folder = self.model('folder').load(folder['_id'], force=True)
             size += self.model('folder').getSizeRecursive(folder)
         # fix value if incorrect
         if size != doc.get('size'):
