@@ -19,10 +19,12 @@
 
 import cherrypy
 import datetime
+import six
 
 from .model_base import Model, ValidationException
 from girder import events
 from girder.constants import AccessType, CoreEventHandler
+from girder.models.model_base import AccessControlledModel
 from girder.utility import assetstore_utilities, acl_mixin
 
 
@@ -60,9 +62,7 @@ class File(acl_mixin.AccessControlMixin, Model):
             updating its size.
         """
         if file.get('assetstoreId'):
-            assetstore = self.model('assetstore').load(file['assetstoreId'])
-            adapter = assetstore_utilities.getAssetstoreAdapter(assetstore)
-            adapter.deleteFile(file)
+            self.getAssetstoreAdapter(file).deleteFile(file)
 
         if file['itemId']:
             item = self.model('item').load(file['itemId'], force=True)
@@ -94,9 +94,7 @@ class File(acl_mixin.AccessControlMixin, Model):
         :type extraParameters: str or None
         """
         if file.get('assetstoreId'):
-            assetstore = self.model('assetstore').load(file['assetstoreId'])
-            adapter = assetstore_utilities.getAssetstoreAdapter(assetstore)
-            return adapter.downloadFile(
+            return self.getAssetstoreAdapter(file).downloadFile(
                 file, offset=offset, headers=headers, endByte=endByte,
                 contentDisposition=contentDisposition,
                 extraParameters=extraParameters)
@@ -104,8 +102,10 @@ class File(acl_mixin.AccessControlMixin, Model):
             if headers:
                 raise cherrypy.HTTPRedirect(file['linkUrl'])
             else:
+                endByte = endByte or len(file['linkUrl'])
+
                 def stream():
-                    yield file['linkUrl']
+                    yield file['linkUrl'][offset:endByte]
                 return stream
         else:  # pragma: no cover
             raise Exception('File has no known download mechanism.')
@@ -272,12 +272,17 @@ class File(acl_mixin.AccessControlMixin, Model):
         file = self.save(file)
 
         if file.get('assetstoreId'):
-            assetstore = self.model('assetstore').load(file['assetstoreId'])
-            adapter = assetstore_utilities.getAssetstoreAdapter(assetstore)
-            adapter.fileUpdated(file)
+            self.getAssetstoreAdapter(file).fileUpdated(file)
 
         return file
 
+    def getAssetstoreAdapter(self, file):
+        """
+        Return the assetstore adapter for the given file.
+        """
+        assetstore = self.model('assetstore').load(file['assetstoreId'])
+        return assetstore_utilities.getAssetstoreAdapter(assetstore)
+
     def copyFile(self, srcFile, creator, item=None):
         """
         Copy a file so that we don't need to duplicate stored data.
@@ -299,30 +304,40 @@ class File(acl_mixin.AccessControlMixin, Model):
         if item:
             file['itemId'] = item['_id']
         if file.get('assetstoreId'):
-            assetstore = self.model('assetstore').load(file['assetstoreId'])
-            adapter = assetstore_utilities.getAssetstoreAdapter(assetstore)
-            adapter.copyFile(srcFile, file)
+            self.getAssetstoreAdapter(file).copyFile(srcFile, file)
         elif file.get('linkUrl'):
             file['linkUrl'] = srcFile['linkUrl']
 
         return self.save(file)
 
-    def isOrphan(self, file, user=None):
+    def isOrphan(self, file):
         """
         Returns True if this file is orphaned (its item or attached entity is
         missing).
 
         :param file: The file to check.
         :type file: dict
-        :param user: The user for permissions.
-        :type user: dict or None
         """
         if file.get('attachedToId'):
-            return not self.model(file.get('attachedToType')).load(
-                file.get('attachedToId'), user=user)
+            attachedToType = file.get('attachedToType')
+            if isinstance(attachedToType, six.string_types):
+                modelType = self.model(attachedToType)
+            elif isinstance(attachedToType, list) and len(attachedToType) == 2:
+                modelType = self.model(*attachedToType)
+            else:
+                # Invalid 'attachedToType'
+                return True
+            if isinstance(modelType, (acl_mixin.AccessControlMixin,
+                                      AccessControlledModel)):
+                attachedDoc = modelType.load(
+                    file.get('attachedToId'), force=True)
+            else:
+                attachedDoc = modelType.load(
+                    file.get('attachedToId'))
         else:
-            return not self.model('item').load(
-                file.get('itemId'), user=user)
+            attachedDoc = self.model('item').load(
+                file.get('itemId'), force=True)
+        return not attachedDoc
 
     def updateSize(self, file):
         """
