@@ -54,18 +54,6 @@ class Folder(AccessControlledModel):
             'size', 'meta', 'parentId', 'parentCollection', 'creatorId',
             'baseParentType', 'baseParentId'))
 
-    def filter(self, *args, **kwargs):
-        """
-        Preserved override for kwarg backwards compatibility. Prior to the
-        refactor for centralizing model filtering, this method's first formal
-        parameter was called "folder", whereas the centralized version's first
-        parameter is called "doc". This override simply detects someone using
-        the old kwarg and converts it to the new form.
-        """
-        if 'folder' in kwargs:
-            args = [kwargs.pop('folder')] + list(args)
-        return super(Folder, self).filter(*args, **kwargs)
-
     def validate(self, doc, allowRename=False):
         """
         Validate the name and description of the folder, ensure that it is
@@ -145,9 +133,9 @@ class Folder(AccessControlledModel):
             baseParent = pathFromRoot[0]
             doc['baseParentId'] = baseParent['object']['_id']
             doc['baseParentType'] = baseParent['type']
-            self.save(doc, triggerEvents=False)
+            doc = self.save(doc, triggerEvents=False)
         if doc is not None and 'lowerName' not in doc:
-            self.save(doc, triggerEvents=False)
+            doc = self.save(doc, triggerEvents=False)
 
         return doc
 
@@ -761,7 +749,7 @@ class Folder(AccessControlledModel):
                 newFolder[key] = copy.deepcopy(srcFolder[key])
                 updated = True
         if updated:
-            self.save(newFolder, triggerEvents=False)
+            newFolder = self.save(newFolder, triggerEvents=False)
         # Give listeners a chance to change things
         events.trigger('model.folder.copy.prepare', (srcFolder, newFolder))
         # copy items
@@ -832,38 +820,37 @@ class Folder(AccessControlledModel):
 
         return doc
 
-    def isOrphan(self, folder, user=None):
+    def isOrphan(self, folder):
         """
         Returns True if this folder is orphaned (its parent is missing).
 
         :param folder: The folder to check.
         :type folder: dict
-        :param user: The user for permissions.
-        :type user: dict or None
         """
         return not self.model(folder.get('parentCollection')).load(
-            folder.get('parentId'), user=user)
+            folder.get('parentId'), force=True)
 
-    def updateSize(self, doc, user):
+    def updateSize(self, doc):
         """
         Recursively recomputes the size of this folder and its underlying
         folders and fixes the sizes as needed.
 
         :param doc: The folder.
         :type doc: dict
-        :param user: The admin user for permissions.
-        :type user: dict
         """
         size = 0
         fixes = 0
         # recursively fix child folders but don't include their size
-        children = self.childFolders(doc, 'folder', user)
+        children = self.model('folder').find({
+            'parentId': doc['_id'],
+            'parentCollection': 'folder'
+        })
         for child in children:
-            _, f = self.model('folder').updateSize(child, user)
+            _, f = self.model('folder').updateSize(child)
             fixes += f
         # get correct size from child items
         for item in self.childItems(doc):
-            s, f = self.model('item').updateSize(item, user)
+            s, f = self.model('item').updateSize(item)
             size += s
             fixes += f
         # fix value if incorrect
