@@ -53,18 +53,6 @@ class Item(acl_mixin.AccessControlMixin, Model):
             'creatorId', 'folderId', 'name', 'baseParentType', 'baseParentId',
             'copyOfItem'))
 
-    def filter(self, *args, **kwargs):
-        """
-        Preserved override for kwarg backwards compatibility. Prior to the
-        refactor for centralizing model filtering, this method's first formal
-        parameter was called "item", whereas the centralized version's first
-        parameter is called "doc". This override simply detects someone using
-        the old kwarg and converts it to the new form.
-        """
-        if 'item' in kwargs:
-            args = [kwargs.pop('item')] + list(args)
-        return Model.filter(self, *args, **kwargs)
-
     def _validateString(self, value):
         """
         Make sure a value is a string and is stripped of whitespace.
@@ -131,9 +119,9 @@ class Item(acl_mixin.AccessControlMixin, Model):
             baseParent = pathFromRoot[0]
             doc['baseParentId'] = baseParent['object']['_id']
             doc['baseParentType'] = baseParent['type']
-            self.save(doc, triggerEvents=False)
+            doc = self.save(doc, triggerEvents=False)
         if doc is not None and 'lowerName' not in doc:
-            self.save(doc, triggerEvents=False)
+            doc = self.save(doc, triggerEvents=False)
 
         return doc
 
@@ -383,7 +371,7 @@ class Item(acl_mixin.AccessControlMixin, Model):
                 newItem[key] = copy.deepcopy(srcItem[key])
         # add a reference to the original item
         newItem['copyOfItem'] = srcItem['_id']
-        self.save(newItem, triggerEvents=False)
+        newItem = self.save(newItem, triggerEvents=False)
 
         # Give listeners a chance to change things
         events.trigger('model.item.copy.prepare', (srcItem, newItem))
@@ -464,27 +452,23 @@ class Item(acl_mixin.AccessControlMixin, Model):
             return True
         return file['mimeType'] in mimeFilter
 
-    def isOrphan(self, item, user=None):
+    def isOrphan(self, item):
         """
         Returns True if this item is orphaned (its folder is missing).
 
         :param item: The item to check.
         :type item: dict
-        :param user: The user for permissions.
-        :type user: dict or None
         """
         return not self.model('folder').load(
-            item.get('folderId'), user=user)
+            item.get('folderId'), force=True)
 
-    def updateSize(self, doc, user):
+    def updateSize(self, doc):
         """
         Recomputes the size of this item and its underlying
         files and fixes the sizes as needed.
 
         :param doc: The item.
         :type doc: dict
-        :param user: The admin user for permissions.
-        :type user: dict
         """
         # get correct size from child files
         size = 0
